import SustainableWebDesign from "./sustainable-web-design.js";
describe("sustainable web design model", () => {
  const swd = new SustainableWebDesign();
  const averageWebsiteInBytes = 22577152e-1;
  describe("energyPerByteByComponent", () => {
    it("should return a object with numbers for each system component", () => {
      const groupedEnergy = swd.energyPerByteByComponent(averageWebsiteInBytes);
      expect(groupedEnergy.consumerDeviceEnergy).toBeCloseTo(88564e-8, 8);
      expect(groupedEnergy.networkEnergy).toBeCloseTo(23844e-8, 8);
      expect(groupedEnergy.productionEnergy).toBeCloseTo(3236e-7, 8);
      expect(groupedEnergy.dataCenterEnergy).toBeCloseTo(25547e-8, 8);
    });
  });
  describe("energyPerByte", () => {
    it("should return a number in kilowatt hours for the given data transfer in bytes", () => {
      const energyForTransfer = swd.energyPerByte(averageWebsiteInBytes);
      expect(energyForTransfer).toBeCloseTo(170316e-8, 7);
    });
  });
  describe("perByte", () => {
    it("should return a single number for CO2 emissions", () => {
      expect(typeof swd.perByte(22577152e-1)).toBe("number");
    });
  });
  describe("energyPerVisit", () => {
    it("should return a number", () => {
      expect(typeof swd.energyPerVisit(averageWebsiteInBytes)).toBe("number");
    });
    it("should calculate the correct energy", () => {
      expect(swd.energyPerVisit(averageWebsiteInBytes)).toBe(0.001285882415771485);
    });
    it("should match the old calculations", () => {
      const v9currentEnergyCalc = swd.energyPerVisit(averageWebsiteInBytes);
      const v8VersionEnergyCalc = swd.energyPerVisitV8(averageWebsiteInBytes);
      expect(swd.emissionsPerVisitInGrams(v9currentEnergyCalc)).toEqual(0.57);
      expect(swd.emissionsPerVisitInGrams(v8VersionEnergyCalc)).toEqual(0.2);
    });
  });
  describe("emissionsPerVisitInGrams", () => {
    it("should calculate the correct co2 per visit", () => {
      const energy = swd.energyPerVisit(averageWebsiteInBytes);
      expect(swd.emissionsPerVisitInGrams(energy)).toEqual(0.57);
    });
    it("should accept a dynamic KwH value", () => {
      const energy = swd.energyPerVisit(averageWebsiteInBytes);
      expect(swd.emissionsPerVisitInGrams(energy, 245)).toEqual(0.32);
    });
  });
  describe("annualEnergyInKwh", () => {
    it("should calculate the correct energy in kWh", () => {
      expect(swd.annualEnergyInKwh(averageWebsiteInBytes)).toBe(27092582400);
    });
  });
  describe("annualEmissionsInGrams", () => {
    it("should calculate the corrent energy in grams", () => {
      expect(swd.annualEmissionsInGrams(averageWebsiteInBytes)).toBe(27092582400);
    });
  });
  describe("annualSegmentEnergy", () => {
    it("should return the correct values", () => {
      expect(swd.annualSegmentEnergy(averageWebsiteInBytes)).toEqual({
        consumerDeviceEnergy: 11740119e-1,
        dataCenterEnergy: 338657.28,
        networkEnergy: 316080.13,
        productionEnergy: 428965.89
      });
    });
  });
});
